'use client'

import { login, signup } from '@/server/actions/auth';
import { zodResolver } from '@hookform/resolvers/zod';
import { useForm } from 'react-hook-form';
import { z } from 'zod';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import {
  Form,
  FormField,
  FormControl,
  FormDescription,
  FormLabel,
  FormMessage,
  FormItem,
} from '@/components/ui/form';

const formSchema = z.object({
  fullName: z.string(),
  email: z.string().email("Must be a vaild email!"),
  password: z.string().min(8, "Must be at least 8 characters!"),
});

const LoginForm = () => {

  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      fullName: '',
      email: '',
      password: '',
    },
  });

  return (
    <Form {...form}>
      <FormField
        control={form.control}
        name="fullName"
        render={({ field }) => (
          <FormItem>
            <FormLabel htmlFor='fullName'>
              Full Name
            </FormLabel>
            <FormControl>
              <Input id='fullName' type='text' {...field} />
            </FormControl>
            <FormDescription>
              Full name is only required when signing up.
            </FormDescription>
            <FormMessage />
          </FormItem>
        )}
      />
      <FormField
        control={form.control}
        name="email"
        render={({ field }) => (
          <FormItem>
            <FormLabel htmlFor='email'>
              Email:
            </FormLabel>
            <FormControl>
              <Input id='email' type='email' {...field} required />
            </FormControl>
            <FormMessage />
          </FormItem>
        )}
      />
      <FormField
        control={form.control}
        name="password"
        render={({ field }) => (
          <FormItem>
            <FormLabel>
              Password:
            </FormLabel>
            <FormControl>
              <Input id='password' type='password' {...field} required />
            </FormControl>
            <FormMessage />
          </FormItem>
        )}
      />
      <Button formAction={login}>
        Log in
      </Button>
      <Button formAction={signup}>
        Sign up
      </Button>
    </Form>
  );
};
export default LoginForm;
